@@ -13,12 +13,19 @@ sub client_test {
    my $site = $client->get("http://www.cpan.org");
    return 1 if ($client->status_message =~ /200 OK/);
 }
-   
+
+sub header_test {
+   my $client = HTTP::Client->new("NewBot/1.0");
+   my $site = $client->get("http://www.cpan.org");
+   my @headers = $client->response_headers;
+   return 1 if (@headers);
+}
    
    
    
 test (1, "loading", sub { use HTTP::Client; 1; });
 test (2, "checking that get works", \&client_test);
+test (3, "checking that headers work", \&header_test);
 
 sub test {
    my ($number, $purpose, $test) = (shift, shift, shift);
